if [ -z ${CONDA_BUILD+x} ]; then
    source /opt/concourse/worker/volumes/live/ca2c1227-b137-4ea8-56f4-91ecdbbfd416/volume/pymongo_1626310144697/work/build_env_setup.sh
fi
python setup.py install --single-version-externally-managed --record=record.txt